@@ -31,14 +31,15 @@ typedef struct {
 	char       *original_path;    /* path read from command line. */
 	char       *full_path;        /* "/" + original_path. */
 	char       *link;
-	guint64     size;
+	goffset     size;
 	time_t      modified;
 
 	char       *name;             /* The file name. */
 	char       *path;             /* The directory. */
 	gboolean    encrypted;        /* Whether the file is encrypted. */
 	gboolean    dir;              /* Whether this is a directory listed in the archive */
-	guint64     dir_size;
+	goffset     dir_size;
+	const char *content_type;
 	
 	/* Additional data. */
 
@@ -49,20 +50,16 @@ typedef struct {
 
 	/* Private data */
 
-	guint       mime_type;
 	gboolean    free_original_path;
 } FileData;
 
 #define FR_TYPE_FILE_DATA (file_data_get_type ())
 
-GType           file_data_get_type                  (void);
-FileData *      file_data_new                       (void);
-FileData *      file_data_copy                      (FileData *src);
-void            file_data_free                      (FileData *fdata);
-const char *    file_data_get_mime_type             (const FileData *fdata);
-const char *    file_data_get_mime_type_description (const FileData *fdata);
-gboolean        file_data_is_dir                    (const FileData *fdata);
-
-void            file_data_release_data (void);
+GType           file_data_get_type            (void);
+FileData *      file_data_new                 (void);
+FileData *      file_data_copy                (FileData *src);
+void            file_data_free                (FileData *fdata);
+void            file_data_update_content_type (FileData *fdata);
+gboolean        file_data_is_dir              (FileData *fdata);
 
 #endif /* FILE_DATA_H */
